.. toctree::
   :maxdepth: 2

.. mdinclude:: ../../README.md

Table of Contents
-----------------
.. toctree::
   :caption: Library
   :maxdepth: 1

   Github <https://github.com/tataratat/napf>
   API Reference <api_reference>

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
